powered by
This function uses the results of the ww_dvUSGS object to generate mean, maximum, median, standard deviation and coefficient of variation per water year per month.
ww_wymUSGS(procDV, sites = NULL, parallel = FALSE, verbose = TRUE, ...)
A tibble filtered by water year and month with added meta-data.
tibble
A previously created ww_dvUSGS object.
A character vector with NWIS site numbers (optional).
character
logical indicating whether to use future_map().
logical
logical for printing information. TRUE (default).
arguments to pass on to future_map and ww_dvUSGS.
if (FALSE) { library(whitewater) yaak_river_dv <- ww_dvUSGS('12304500', parameter_cd = '00060', wy_month = 10) yaak_river_wym <- ww_wymUSGS(yaak_river_dv) }
Run the code above in your browser using DataLab